function [coverage width]=computeCoverage(statistics,probabilities,dens,grid,z)

% Computes coverage and average width of confidence bounds.
%
% See: computeStatistics, copulaPredictDensity, copulaCVDensity
%
% Inputs:
%
% statistics......the output of computeStatistics(grid,dens,[],z)
%
% probabilities...the confidence level, e.g. if probabilities=97.5, then
%                 the 97.5% confidence interval is considered
%
% dens............(predictive) density computed on a grid e.g. by
%                  copulaPredictDensity
%
% grid............the grid on which the density is available
%
% z...............observations (z-values, data.z)           
%
% Outputs:
%
% coverage........percentages of coverage of the true values by the
%                 confidence intervals
% 
% width...........average width of probability intervals that include the
%                 true values "z"
%  
% Hannes Kazianka, August 2011

    if nargin<5
        z=[];
        grid=[];
        dens=[];
        width=[];
    end
    if nargin<2
        probabilities=0.02:0.02:0.98;
    end

    n=length(statistics.PIT);
    coverage=zeros(1,length(probabilities));

    for i=1:n
        coverage=coverage+(((1-probabilities)/2)<statistics.PIT(i) & statistics.PIT(i)<=((1+probabilities)/2));
    end
    coverage=coverage./n;

    if nargout==2 && ~isempty(z)
        statistics=computeStatistics(dens,grid,[(1-probabilities)/2 (1+probabilities)/2],z);
        width=zeros(length(probabilities),1);%average width of probability intervals that include the true values (should be as small as possible)
        for i=1:length(probabilities)
            width(i)=1/(n*coverage(i))*sum(((((1-probabilities(i))/2)<statistics.PIT & statistics.PIT<=((1+probabilities(i))/2))).*(statistics.quantiles(:,length(probabilities)+i)-statistics.quantiles(:,i)));
        end
    end


    plot(probabilities,coverage,'b')
    hold on;plot([0 1],[0 1],'r')
    xlabel('Probability interval - p')
    ylabel('Proportion in this interval')