function [cv stat]=copulaCV(data,model,search,options)

% Performs (leave one out) cross validation and computes associated statistics
%
% See: copulaPredict
%
% Inputs:
%
% data........the data set as a structure array of the format data.x (x-coordinates), data.y
%             (y-coordinates), data.z (measured values)
%
% model.......contains the parameters of the spatial copula model (see
%             function initialize)
%
% search......search radius for interpolation
%
% options.....options structure array (see function testOptions)
%
% Outputs:
%
% cv..........cross validation predictions
%
% stat........cross validation summary statistics
%             stat.mse.....mean squared error
%             stat.corr....correlation between true and predicted values
%             stat.mae.....mean absolute error
%             stat.mad.....median absolute deviation
%             stat.bias....prediction bias
%
% Hannes Kazianka, August 2011

    options=testOptions(options);
    
    n=length(data.x);
    cv=zeros(n,1);
    if options.parallel==1
        if matlabpool('size')==0
            matlabpool
        end
        options.parallel=0;
        parfor i=1:n
            cv(i)=copulaCVLoop(i,data,model,search,n,options);
        end
    else
        for i=1:n
            cv(i)=copulaCVLoop(i,data,model,search,n,options);
        end
    end

    stat.mse=mean((data.z-cv).^2);
    stat.corr=corr(data.z,cv);
    stat.mae=mean(abs(data.z-cv));
    stat.mad=median(abs(data.z-cv));
    stat.bias=mean(cv-data.z);
    
function cv=copulaCVLoop(i,data,model,search,n,options)
    locationsnew.x=data.x(i);
    locationsnew.y=data.y(i);
    locationsnew.z=data.z(i);
    locationsnew.F=model.trend.F(i,:);
    data.z=data.z(setdiff(1:n,i));
    data.x=data.x(setdiff(1:n,i));
    data.y=data.y(setdiff(1:n,i));
    model.trend.F=model.trend.F(setdiff(1:n,i),:);
    calc.mean=1;
    calc.quantiles=[];
    calc.std=0;
    temp=options.print;
    options.print=0;
    prediction=copulaPredict(locationsnew,data,model,search,calc,options);
    options.print=temp;        
    if options.print>=1
        disp(['Prediction: Location ' num2str(i)]);
    end
    if options.print>=2
        disp(['True: ' num2str(locationsnew.z) ', Predicted: ' num2str(prediction.mean)]);
    end
    cv=prediction.mean;