function dens=copulaCVDensity(data,model,search,grid,options)

% Calculates (leave one out) cross validation predictive densities
%
% See: copulaPredictDensity
%
% Inputs:
%
% data........the data set as a structure array of the format data.x (x-coordinates), data.y
%             (y-coordinates), data.z (measured values)
%
% model.......contains the parameters of the spatial copula model (see
%             function initialize)
%
% search......search radius for interpolation
%
% grid........the grid on which the density is computed (discretization of
%             the support of the predictive distribution)
%
% options.....options structure array (see function testOptions)
%
% Outputs:
%
% dens........matrix (number of observations x grid size) consisting of the
%             cross validation predictive densities
%
% Hannes Kazianka, August 2011

    options=testOptions(options);

    n=length(data.x);
    dens=zeros(n,length(grid));
    if options.parallel==1
        if matlabpool('size')==0
            matlabpool
        end
        options.parallel=0;
        parfor i=1:n
            dens(i,:)=copulaCVDensityLoop(i,data,model,search,grid,n,options);
        end
    else
        for i=1:n
            dens(i,:)=copulaCVDensityLoop(i,data,model,search,grid,n,options);
        end
    end

function dens=copulaCVDensityLoop(i,data,model,search,grid,n,options)
	locationsnew.x=data.x(i);
	locationsnew.y=data.y(i);
	locationsnew.z=data.z(i);
    locationsnew.F=model.trend.F(i,:);
    data.z=data.z(setdiff(1:n,i));
	data.x=data.x(setdiff(1:n,i));
	data.y=data.y(setdiff(1:n,i));
    model.trend.F=model.trend.F(setdiff(1:n,i),:);
    temp=options.print;
    options.print=0;
    dens=copulaPredictDensity(locationsnew,data,model,search,grid,options);
    options.print=temp;        
    if options.print>=1
        disp(['Prediction: Location ' num2str(i)]);
    end
