function rho = empiricalSpearmanRho(data,lags)

% Computes the empirical Spearman rank correlation for the given lags based
% on the empirical copula.
%
% See: empiricalCopula
%
% Inputs:
%
% data........the data set as a structure array of the format data.x (x-coordinates), data.y
%             (y-coordinates), data.z (measured values)
%
% lags........lag classes to investigate
%
% Outputs:
%
% rho.........vector of empirical Spearman rank correlations
%
% Hannes Kazianka, August 2011


    rho=zeros(length(lags)-1,1);

    [~, S]=empiricalCopula(data,lags);
    for k=1:(length(lags)-1)
        if isempty(S{k})
            lags=lags(1:(k-1));
            break;
        end
    end

    for k=1:(length(lags)-1)
        c=corr(S{k},'type','Spearman'); 
        rho(k)=c(1,2);
    end


