function empvario= empiricalVariogram(data,lags)

% Computes the empirical variogram
%
% Inputs:
%
% data........the data set as a structure array of the format data.x (x-coordinates), data.y
%             (y-coordinates), data.z (measured values)
%
% lags........lag classes to investigate
%
% Outputs:
%
% empvario....structure array consisting of different variogram estimates
%             empvario.v......the classical variogram estimator
%             empvario.vCH1...Cressie-Hawkins estimator
%             empvario.vCH2...Cressie-Hawkins estimator using the median
%             empvario.lagh...mean of distances between observations in the lag classes
%             empvario.n......number of observations in the lag classes
%
% Hannes Kazianka, August 2012

if nargin<2 || isempty(lags)
	scale = (0.35 * sqrt((max(data.x) - min(data.x))^2 + (max(data.y) - min(data.y))^2)/100);
    lags = [2, 4, 6, 9, 12, 15, 25, 35, 50, 65, 80, 100]*scale;
end
    
empvario.var=var(data.z);
empvario.num=length(data.x);
h=pdist([data.x data.y]);
h=squareform(h);
diff=pdist(data.z);
diff=squareform(diff);
squareddiff=diff.^2;
sqrtdiff=abs(diff).^(1/2);
h=h(:);
squareddiff=squareddiff(:);
sqrtdiff=sqrtdiff(:);

nlc=length(lags)-1;
v=NaN.*ones(nlc,1);
n=v;
vCH1=v;
vCH2=v;
lagh=v;
for i=1:nlc
    ind=find(h>lags(i) & h<=lags(i+1));
    v(i)=mean(squareddiff(ind))/2;   
    n(i)=length(ind);
    vCH1(i)=mean(sqrtdiff(ind))^4/(2*(0.457+0.494/n(i)));
    vCH2(i)=median(squareddiff(ind))/(2*0.455);
    lagh(i)=mean(h(ind));
end

index=(n>0);
empvario.v=v(index);
empvario.vCH2=vCH2(index);
empvario.vCH1=vCH1(index);
empvario.lagh=lagh(index);
empvario.n=n(index);