function [params,MSE]=fitVariogram(empvario,correlation,options)

% Fits a theoretical variogram to an empirical variogram. Used by the
% function initialize.
%
% See: initialize, empiricalVariogram
%
% Inputs:
%
% empvario......output of the function empiricalVariogram
%
% correlation...correlation structure as set by initialize
%               (model.correlation)
%
% options.......options structure array (see function testOptions)
%
% Outputs:
%
% params........parameters of the optimal correlation model
%
% MSE...........the optimal Mean Squared Error
%  
% Hannes Kazianka, August 2011

    options=testOptions(options);

    [params,MSE]=fmincon(@criterium,[mean([max(empvario.v),median(empvario.v)]) correlation.params],[],[],[],[],[0.001 correlation.lower],[max(empvario.v)*10 correlation.upper],[],options.optim,empvario,correlation,options);
    
    if options.print>=1
        figure;scatter(empvario.lagh,empvario.v);
        hold on;plot(empvario.lagh,params(1).*(correlCovMat(0,params(2:end),correlation.model)-correlCovMat(empvario.lagh,params(2:end),correlation.model)),'k');   
    end
    params=params(2:end);
    
function z=criterium(params,empvario,correlation,options)

    gamma=params(1)*(correlCovMat(0,params(2:end),correlation.model)-correlCovMat(empvario.lagh,params(2:end),correlation.model));
    var= 2*(gamma.^2)./empvario.n;
    summand=((gamma-empvario.v).^2)./var;
    z=sum(summand);
    if options.print>=2
        disp(num2str([z params]));
    end