function y = mvnlogpdf_noconst(X, Sigma)

% Computes the logarithm of the PDF of a multivariate Gaussian
% distribution with zero mean up to additive constants. Adapted
% from the Matlab function mvnpdf.
%
% See: mvnpdf
%
% Inputs:
%
% X.......vector of values at which the log-PDF is sought
%
% Sigma...covariance matrix 
%
% Outputs:
%
% y......logarithm of the multivariate Gaussian PDF at X up to additive
%        constants
%
% Hannes Kazianka, August 2011

        
        [R,err] = chol(Sigma,'upper');
        if err ~= 0
            error('stats:mvnpdf:BadCovariance', ...
                  'SIGMA must be symmetric and positive definite.');
        end
        
        xRinv = X / R;
        logSqrtDetSigma = sum(log(diag(R)));

        quadform = sum(xRinv.^2, 2);

        y =-0.5*quadform - logSqrtDetSigma;

        
 