function plotCI(manystatistics,z)

% Plots two different quantiles (of the predictive distribution) for every
% location.
%
% See: computeStatistics
%
% Inputs:
%
% manystatistics...either a cell array that contains a number of statistics
%                  (outputs of computeStatistics), or the output of
%                  computeStatistics
%
% z................the measured values at the locations for which the
%                  statistics have been computed
%
% Hannes Kazianka, August 2011

    if nargin<2
        z=[];
    end
    figure;
    if iscell(manystatistics)
        m=length(manystatistics);
        for i=1:m
            plotthequantiles(manystatistics{i},z,m,i);
        end
    else
        plotthequantiles(manystatistics,z,1,1);
    end
    
    
    
function plotthequantiles(statistics,data,m,i)

    quantiles=statistics.quantiles;

    [n,q]=size(quantiles);
    if q~=2
        quantiles=quantiles(:,1:2);
    end

    xvalues=[1:n;1:n];
    yvalues=[quantiles(:,1)';quantiles(:,2)'];
    subplot(m,1,i);plot(xvalues,yvalues,'r','LineWidth',1.5);
    if ~isempty(data) && length(data)==n
        hold on;plot(xvalues(1,:),data,'.k');
        r=(data-statistics.mean)./statistics.std;
        title(['Standardized residuals: ' num2str(round(10000*mean(r))/10000)]);
    end

