function plotIK(IKoutput,locations,ncontours,gridsize,dist)

% Plots empirical copula and theoretical copula density for different lag
% classes on a grid
%
% See: copulaIK
%
% Inputs:
%
% IKoutput....output of the copulaIK function
%
% locations...the locations at which indicator kriging has been performed
%
% ncontours...the number of contours in the contour plot
%
% gridsize....the size of the grid on which the indicator kriging results
%             are displayed
% 
% dist........maximum distance between plotted locations and known
%             locations
%  
% Hannes Kazianka, August 2011

    if nargin<5 || isempty(dist)
        dist=Inf;
    end
    if nargin<4 || isempty(gridsize)
        gridsize=min([abs((max(locations.x)-min(locations.x))/length(locations.x)),abs((max(locations.y)-min(locations.y))/length(locations.x))]);
    end
    Zhat=IKoutput.pred;
    k=size(Zhat,2);

    origlocations.x=locations.x(~isnan(locations.x));
    origlocations.y=locations.y(~isnan(locations.y));
    [xi,yi] = meshgrid(min(origlocations.x):gridsize:max(origlocations.x),min(origlocations.y):gridsize:max(origlocations.y)); 
    for i=1:k
        origlocations.z=Zhat(:,i);
        inter=griddata(origlocations.x,origlocations.y,origlocations.z,xi,yi,'linear');
        s=size(inter);
        inter=inter(:);
        xi=xi(:);
        yi=yi(:);
        if ~isinf(dist)
            for j=1:length(xi)
                h=sqrt((xi(j)-origlocations.x).^2+(yi(j)-origlocations.y).^2);
                if min(h)>dist
                    inter(j)=NaN;
                end
            end
        end
        xi=reshape(xi,s);
        yi=reshape(yi,s);
        inter=reshape(inter,s);
        figure;[~,conth]=contourf(xi,yi,inter,ncontours);
        colormap gray
        xlabel('x_1','FontWeight','bold','FontSize',12);
        ylabel('x_2','FontWeight','bold','FontSize',12);
        set(gca,'FontWeight','bold','FontSize',10);
        set(conth,'LevelList',[min(0,min(min(inter))) 0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9 0.99]);
        set(gca,'CLim',[0 1]);
        title(['P(Z(x)\leq' num2str(IKoutput.thres(i)) ')'],'FontSize',12,'FontWeight','bold')
    end