function output=plotIKCov(thres,grid,model)

% Plots the indicator covariances for different models on a grid. Does not
% consider a spatial trend.
%
% See: copulaIK
%
% Inputs:
%
% thres.......thresholds, for which the indicator covariances are computed
%
% grid........the grid on which the covariance function is computed and
%             displayed
% 
% model.......either a cell array that contains a number of models, or a
%             structure array that has the format of the output of the
%             function initialize 
%
% Outputs:
%
% output......indicator covariances as an array of dimension:
%             length(grid) x length(thres) x length(model)
%  
% Hannes Kazianka, August 2011

    k=length(thres);
    if isstruct(model)
        temp=cell(0);
        temp{1}=model;
        model=temp;
        clear temp
    end

    if iscell(model)
        for i=1:length(model)
            output=zeros(k^2,length(grid),length(model));
            if length(model{i}.margin.params)==1
                thresnew=feval([model{i}.margin.name 'cdf'],thres,model{i}.trend.params(1),model{i}.margin.params);
            elseif length(model{i}.margin.params)==2
                thresnew=feval([model{i}.margin.name 'cdf'],thres,model{i}.trend.params(1),model{i}.margin.params(1),model{i}.margin.params(2));
            end
            for j=1:length(grid)
                output(:,j,i)=covariance(grid(j),kron(thresnew,ones(1,k))',kron(ones(1,k),thresnew)',model{i}.correlation.params,model{i}.correlation.model,model{i}.copula);
            end
        end
    end
    
    figure;
    for j=1:k
        for l=1:k
            for i=1:length(model)
                subplot(k,k,(j-1)*k+l);plot(grid,reshape(output((j-1)*k+l,:,i),length(grid),1),'LineWidth',2);
            end
        end
    end

function val = covariance(h,q1,q2,param,model,copula)
    if h~=0
        if isempty(copula) || strcmp(copula.name,'Gaussian')
            val=gausscop([q1,q2],h,param,model)-q1.*q2;
        else
            switch copula.name
                case 'Chi2' 
                    val=chi2cop([q1,q2],h,param,model,copula.params)-q1.*q2;
                case 'Student'
                    val=studentcop([q1,q2],h,param,model,copula.params)-q1.*q2;
            end
        end
    else
        val=min([q1;q2])-q1.*q2;
    end
   

function val = gausscop(x,h,delta,model)
    cov=correlCovMat(h,delta,model);
    sigma=[1 cov;cov 1];
    x=norminv(x,0,1);
    val=mvncdf(x,[0 0],sigma);
    
function val =studentcop(x,h,delta,model,nu)
    cov=correlCovMat(h,delta,model);
    sigma=[1 cov;cov 1];
    x=tinv(x,nu);
    val=mvtcdf(x,sigma,nu);
        
function val =chi2cop(x,h,delta,model,lambda)
    cov=correlCovMat(h,delta,model);
    sigma=[1 cov;cov 1];
    x=sqrt(ncx2inv(x,1,lambda));
    m=[sqrt(lambda) sqrt(lambda)];
    val=mvncdf(x,m,sigma)-mvncdf([x(:,1) -x(:,2)],m,sigma)-mvncdf([-x(:,1) x(:,2)],m,sigma)+mvncdf(-x,m,sigma);