function plotPIT(locations,PITvalues,limits)

% Plots PIT values for assessing the calibration of the model.
%
% See: computeStatistics
%
% Inputs:
%
% locations...the locations as a structure array of the format locations.x 
%             (x-coordinates), locations.y (y-coordinates)
% 
% PITvalues...the PIT values, typically computed by computeStatistics
% 
% limits......a two-dimensional vector containing the limits beyond which
%             the locations should be highlighted when plotting, e.g. [0.025 0.975].
%  
% Hannes Kazianka, August 2011


    if nargin<3
        limits=[0 1];
    end

    PITvalues=round(PITvalues*100)/100;
    p1=find(PITvalues<limits(1));
    p3=find(PITvalues>limits(2));
    p2=find(PITvalues>=limits(1) & PITvalues<=limits(2));figure;
    if ~isempty(p1)
        text(locations.x(p1),locations.y(p1),num2str(PITvalues(p1)),'Color','b','FontWeight','bold','Interpreter','none');
    end
    if ~isempty(p2)
        text(locations.x(p2),locations.y(p2),num2str(PITvalues(p2)),'Color','k','Interpreter','none');
    end
    if ~isempty(p3)
        text(locations.x(p3),locations.y(p3),num2str(PITvalues(p3)),'Color','r','FontWeight','bold','Interpreter','none');
    end
    xlim([min(locations.x)-0.1*(max(locations.x)-min(locations.x)),max(locations.x)+0.1*(max(locations.x)-min(locations.x))])
    ylim([min(locations.y)-0.1*(max(locations.y)-min(locations.y)),max(locations.y)+0.1*(max(locations.y)-min(locations.y))])
    xlabel('x');
    ylabel('y');