function [emprho theorrho]=plotSpearmanRho(data,lags,grid,model)

% Computes and plots the empirical and theoretical Spearman rank correlation coefficient for different lag
% classes.
%
% See: spearmanRho, empiricalSpearmanRho
%
% Inputs:
%
% data........the data set as a structure array of the format data.x (x-coordinates), data.y
%             (y-coordinates), data.z (measured values)
%
% lags........a vector containing the different lag classes
%
% grid........grid on which the theoretical Spearman rank correlation curve
%             should be computed and displayed
% 
% model.......either a cell array that contains a number of models, or a
%             structure array that has the format of the output of the
%             function initialize 
%
% Outputs:
%
% emprho......the empirical Spearman rank correlation coefficients for the
%             different lag classes
%
% theorrho....the theoretical Spearman rank correlation curve 
%  
% Hannes Kazianka, August 2011
    
    emprho = empiricalSpearmanRho(data,lags);
    figure;
    scatter(diff(lags)./2+lags(1:(end-1)),emprho,'LineWidth',2);
    if nargin==4 && iscell(model)
        theorrho=zeros(length(model),length(grid));
        for i=1:length(model)
            theorrho(i,:)=spearmanRho(grid,model{i}.copula,model{i}.correlation);
            hold on;plot(grid,theorrho(i,:));
        end
    elseif nargin==4 && isstruct(model)
        theorrho=spearmanRho(grid,model.copula,model.correlation);
        hold on;plot(grid,theorrho);
    end