function data = simulateData(x,y,model)

% Generates a realization of the random field specified by model at
% predefined locations
%
% See: initialize
%
% Inputs:
%
% x...........x-coordinates of the data
%
% y...........y-coordinates of the data
% 
% model.......defines the spatial copula model (must be in the format of the output
%             of the function initialize) 
%
% Outputs:
%
% data........the random field realization
%  
% Hannes Kazianka, August 2012

    data.x=x;
    data.y=y;
    if ~isempty(model.anisotropy)
        xy=[cos(model.anisotropy.params(1)),sin(model.anisotropy.params(1));-model.anisotropy.params(2)*sin(model.anisotropy.params(1)),model.anisotropy.params(2)*cos(model.anisotropy.params(1))]*[data.x';data.y'];
        x=xy(1,:)';
        y=xy(2,:)';
    end
    h=pdist([x y]);
    h=squareform(h);


    cov=correlCovMat(h,model.correlation.params,model.correlation.model);

    if isempty(model.copula) || strcmp(model.copula.name,'Gaussian')
        data.z=mvnrnd(zeros(1,length(x)),cov,1)';
        data.z=normcdf(data.z);
    
    else
        switch model.copula.name
            case 'Chi2'
                m=ones(1,length(x)).*sqrt(model.copula.params);
                data.z=mvnrnd(m,cov,1)';
                data.z=data.z.^2;
                data.z=ncx2cdf(data.z,1,model.copula.params);
            case 'Student'
                data.z=mvtrnd(cov,model.copula.params,1)';
                data.z=tcdf(data.z,model.copula.params);
        end
    end

    expected=model.trend.F*model.trend.params';
    if isempty(model.margin.params)
        data.z=feval([model.margin.name 'inv'],data.z,expected);
    elseif length(model.margin.params)==1
        data.z=feval([model.margin.name 'inv'],data.z,expected,model.margin.params); 
    elseif length(model.margin.params)==2
        data.z=feval([model.margin.name 'inv'],data.z,expected,model.margin.params(1),model.margin.params(2));
    end