function options=testOptions(options)

% Updates the options structure array which is used throughout the code.
%
% options.tol........the tolerance level at which to stop the optimization 
%                    procedures
% options.print......intensity of the notification about progam status
%                    (1,2,3)
% options.optim......optimset array for tuning optimization procedures
% options.parallel...whether or not to use the Parallel Computing Toolbox 
%
% Inputs:
%
% options.......options structure array to check
%
% Outputs:
%
% options......updated options
%  
% Hannes Kazianka, August 2011

    if isempty(options) || ~isstruct(options)
        options.tol=0.001;
        options.print=2;
        options.parallel=0;
        %R2007a
        %options.optim=optimset('LargeScale','off','MaxIter',1000,'MaxFunEvals',5000,'Display','off');
        %R2010a
        options.optim=optimset('LargeScale','off','MaxIter',1000,'MaxFunEvals',5000,'Display','off','Algorithm','active-set');
    else
        if ~isfield(options,'tol') || ~isnumeric(options.tol) || options.tol<=0
            options.tol=0.001;
        end
        if ~isfield(options,'print') || ~isnumeric(options.print)
            options.print=2;
        end
        if ~isfield(options,'optim') 
            %R2007a
            %options.optim=optimset('LargeScale','off','MaxIter',1000,'MaxFunEvals',5000,'Display','off');
            %R2010a
            options.optim=optimset('LargeScale','off','MaxIter',1000,'MaxFunEvals',5000,'Display','off','Algorithm','active-set');
        end
        if ~isfield(options,'parallel')
            options.parallel=0;
        end
    end
            
    