function visualize(locations,z,ncontours,gridsize,dist)

% Contour plot and surface plot (linear interpolation) of the data (z)
%
% Inputs:
%
% locations....the locations as a structure array of the format locations.x
%             (x-coordinates), locations.y (y-coordinates)
%             
% z............the measured values
%
% ncontours....the number of contours in the contour plot
%
% gridsize.....the size of the grid on which the data are displayed
% 
% dist.........maximum distance between plotted locations and known
%             locations
%  
% Hannes Kazianka, August 2011

    if nargin<5 || isempty(dist)
        dist=Inf;
    end
    if nargin<4 || isempty(gridsize)
        gridsize=min([abs((max(locations.x)-min(locations.x))/length(locations.x)),abs((max(locations.y)-min(locations.y))/length(locations.x))]);
    end
    [xi,yi] = meshgrid(min(locations.x):gridsize:max(locations.x),min(locations.y):gridsize:max(locations.y)); 
    inter=griddata(locations.x,locations.y,z,xi,yi,'linear');
    s=size(inter);
    inter=inter(:);
    xi=xi(:);
    yi=yi(:);
    if ~isinf(dist)
        for j=1:length(xi)
            h=sqrt((xi(j)-locations.x).^2+(yi(j)-locations.y).^2);
            if min(h)>dist
                inter(j)=NaN;
            end
        end
    end
    xi=reshape(xi,s);
    yi=reshape(yi,s);
    inter=reshape(inter,s);
    figure;contourf(xi,yi,inter,ncontours);colorbar;
    figure;surf(xi,yi,inter);colorbar;